==> nextcloud-28.0.3.tgz: nextcloud/apps/notifications/l10n/ast.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Hola, %s",
    "Hello %s," : "Hola, %s.",
    "_New notification for %s_::_%n new notifications for %s_" : ["%n avisu nuevu de: %s","%n avisos nuevos de: %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Tienes %n avisu nuevu de: %s","Tienes %n avisos nuevos de: %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Pues camudar la frecuencia d'estos mensaxes o desactivalos na <a href=\"%s\">configuración</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Pues camudar la frecuencia d'estos mensaxes o desactivalos na configuración: %s",
    "Admin notifications" : "Avisos de l'alministración",
    "Notifications" : "Avisos",
    "Push notifications - Fair use policy" : "Avisos push - Política d'usu xustu",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH patrocina una pasera d'avisos push gratuita pa usuarios privaos. Pa garantizar un bon serviciu, la pasera llenda'l númberu d'avisos push per sirvidor y si s'algamó la llende nesti sirvidor. Pa usuarios d'empresa, hai disponible una pasera más escalable.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Esta aplicación forne un backend y un frontal pa l'API d'avisos disponible en Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Esta aplicación forne un backend y un frontal pa l'API d'avisos disponible en Nextcloud.\n\t\tL'API úsenla otres aplicaciones p'avisar a los usuarios na IU web y sincronizar los veceros. Dalgunos exemplos:\n\n📬 Compartición de ficheros federada: recibiesti una compartición remota nueva\n\n📑 Comentarios: otru usuariu mentóte nel comentariu d'un ficheru.\n\n🚢 Avisu d'anovamientu: un avisu p'anovar una aplicación o la propia instancia de Nextcloud\n\n📣 Centru d'anuncios: l'alministración espublizó un anunciu",
    "Dismiss" : "Escartar",
    "Contact Nextcloud GmbH" : "Ponese en contautu con Nextcloud GmbH",
    "seconds ago" : "hai segundos",
    "in {path}" : "en {path}",
    "Dismiss all notifications" : "Escartar tolos avisos",
    "Requesting browser permissions to show notifications" : "Solicitando los permisos del restolador p'amosar los avisos",
    "Push notifications might be unreliable" : "Ye posible que los avisos push nun seyan fiables",
    "No notifications" : "Nun hai nengún avisu",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH patrocina una pasera d'avisos push gratuita pa usuarios privaos. Pa garantizar un bon serviciu, la pasera llenda'l númberu d'avisos push per sirvidor. Pa usuarios d'empresa, hai disponible una pasera más escalable. Ponte en contautu con Nextcloud GmbH pa consiguir más información.",
    "Notifications defaults" : "Opciones predeterminaes de los avisos",
    "Configure the default notification settings for new users" : "Configura la configuración predeterminada de los avisos pa usuarios nuevos",
    "Send email reminders about unhandled notifications after:" : "Unviar recordatorios per corréu electrónicu sobre los avisos ensin lleer dempués de:",
    "Play sound when a new notification arrives" : "Reproducir un soníu cuando llegue un avisu",
    "Play sound when a call started (requires Nextcloud Talk)" : "Reproducir un soníu cuando comience una llamada (rique Nextcloud Talk)",
    "Never" : "Enxamás",
    "1 hour" : "1 hora",
    "3 hours" : "3 hores",
    "1 day" : "1 día",
    "1 week" : "1 selmana",
    "Your settings have been updated." : "Anovóse la configuración.",
    "An error occurred while updating your settings." : "Prodúxose un error mentanto s'anovaba la configuración.",
    "You need to set up your email address before you can receive notification emails." : "Tienes de configurar una direición de corréu electrónicu enantes de poder recibir mensaxes d'avisu."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.8.tgz: nextcloud/apps/notifications/l10n/ast.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Hola, %s",
    "Hello %s," : "Hola, %s.",
    "_New notification for %s_::_%n new notifications for %s_" : ["%n avisu nuevu de: %s","%n avisos nuevos de: %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Tienes %n avisu nuevu de: %s","Tienes %n avisos nuevos de: %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Pues camudar la frecuencia d'estos mensaxes o desactivalos na <a href=\"%s\">configuración</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Pues camudar la frecuencia d'estos mensaxes o desactivalos na configuración: %s",
    "Admin notifications" : "Avisos de l'alministración",
    "Notifications" : "Avisos",
    "Push notifications - Fair use policy" : "Avisos push - Política d'usu xustu",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH patrocina una pasera d'avisos push gratuita pa usuarios privaos. Pa garantizar un bon serviciu, la pasera llenda'l númberu d'avisos push per sirvidor y si s'algamó la llende nesti sirvidor. Pa usuarios d'empresa, hai disponible una pasera más escalable.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Esta aplicación forne un backend y un frontal pa l'API d'avisos disponible en Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Esta aplicación forne un backend y un frontal pa l'API d'avisos disponible en Nextcloud.\n\t\tL'API úsenla otres aplicaciones p'avisar a los usuarios na IU web y sincronizar los veceros. Dalgunos exemplos:\n\n📬 Compartición de ficheros federada: recibiesti una compartición remota nueva\n\n📑 Comentarios: otru usuariu mentóte nel comentariu d'un ficheru.\n\n🚢 Avisu d'anovamientu: un avisu p'anovar una aplicación o la propia instancia de Nextcloud\n\n📣 Centru d'anuncios: l'alministración espublizó un anunciu",
    "Failed to perform action" : "Nun se pue facer l'aición",
    "Dismiss" : "Escartar",
    "Contact Nextcloud GmbH" : "Ponese en contautu con Nextcloud GmbH",
    "seconds ago" : "hai segundos",
    "Failed to dismiss notification" : "Nun se pue escartar l'avisu",
    "in {path}" : "en {path}",
    "Dismiss all notifications" : "Escartar tolos avisos",
    "Requesting browser permissions to show notifications" : "Solicitando los permisos del restolador p'amosar los avisos",
    "Push notifications might be unreliable" : "Ye posible que los avisos push nun seyan fiables",
    "No notifications" : "Nun hai nengún avisu",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH patrocina una pasera d'avisos push gratuita pa usuarios privaos. Pa garantizar un bon serviciu, la pasera llenda'l númberu d'avisos push per sirvidor. Pa usuarios d'empresa, hai disponible una pasera más escalable. Ponte en contautu con Nextcloud GmbH pa consiguir más información.",
    "Failed to dismiss all notifications" : "Nun se pudieron escartar tollos avisos",
    "Notifications defaults" : "Opciones predeterminaes de los avisos",
    "Configure the default notification settings for new users" : "Configura la configuración predeterminada de los avisos pa usuarios nuevos",
    "Send email reminders about unhandled notifications after:" : "Unviar recordatorios per corréu electrónicu sobre los avisos ensin lleer dempués de:",
    "Play sound when a new notification arrives" : "Reproducir un soníu cuando llegue un avisu",
    "Play sound when a call started (requires Nextcloud Talk)" : "Reproducir un soníu cuando comience una llamada (rique Nextcloud Talk)",
    "Never" : "Enxamás",
    "1 hour" : "1 hora",
    "3 hours" : "3 hores",
    "1 day" : "1 día",
    "1 week" : "1 selmana",
    "Your settings have been updated." : "Anovóse la configuración.",
    "An error occurred while updating your settings." : "Prodúxose un error mentanto s'anovaba la configuración.",
    "You need to set up your email address before you can receive notification emails." : "Tienes de configurar una direición de corréu electrónicu enantes de poder recibir mensaxes d'avisu."
},
"nplurals=2; plural=(n != 1);");
